==> cheddar-osate2_1.0.0.201901081024.jar: src/cheddar/aadl/To_Address_Space.java <==
package cheddar.aadl;

import org.osate.aadl2.instance.ComponentInstance;
import org.osate.xtext.aadl2.properties.util.GetProperties;

import cheddar.adl.Address_Space;
import cheddar.adl.Objects_Type;
import cheddar.adl.Preemptives_Type;
import cheddar.adl.Schedulers_Type;
import cheddar.adl.Scheduling_Parameters;
import cheddar.osate2_plugin.Debug;

public class To_Address_Space {

	static public void Create_Process_Component(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component) {

		String name = component.getFullName().toString();

		Integer quantum = Properties_With_Default_Value.getScheduler_Quantum(component);
		String source_text = Properties_With_Default_Value.getSource_Text(component);
		Schedulers_Type protocol = Properties_With_Default_Value.getSchedulingProtocol(component);
		Preemptives_Type preemptive = Preemptives_Type.Preemptive;
		if (!Properties_With_Default_Value.getPreemptive_Scheduler(component)) {
			preemptive = Preemptives_Type.Not_Preemptive;
		}

		ComponentInstance co = GetProperties.getBoundProcessor(component);
		String cpu_name = "";
		if (co != null) {
			cpu_name = co.getName();
		}

		// Instanciate Cheddar ADL entities
		//
		Scheduling_Parameters p = new Scheduling_Parameters();
		p.setPreemptiveType(preemptive);
		p.setSchedulerType(protocol);
		p.setUserDefinedSchedulerSourceFileName(source_text);
		p.setQuantum(quantum);

		Address_Space c = new Address_Space();
		c.setName(name);
		c.setObjectType(Objects_Type.Address_Space_Object_Type);
		c.setScheduling(p);
		c.setcheddarXmlId(id.getAndIncrement());
		c.setCpuName(cpu_name);

		Debug.Put("add address space " + c.getName());

		result.address_spaces.add(c);

	}

}

==> cheddar-osate2_1.0.0.202003291034.jar: src/cheddar/aadl/To_Address_Space.java <==
package cheddar.aadl;

import org.osate.aadl2.instance.ComponentInstance;
import org.osate.xtext.aadl2.properties.util.GetProperties;

import cheddar.adl.Address_Space;
import cheddar.adl.Objects_Type;
import cheddar.adl.Preemptives_Type;
import cheddar.adl.Schedulers_Type;
import cheddar.adl.Scheduling_Parameters;
import cheddar.osate2_plugin.Debug;

public class To_Address_Space {

	static public void Create_Process_Component(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component) {

		String name = component.getInstanceObjectPath().toString();

		Integer quantum = Properties_With_Default_Value.getScheduler_Quantum(component);
		String source_text = Properties_With_Default_Value.getSource_Text(component);
		Schedulers_Type protocol = Properties_With_Default_Value.getSchedulingProtocol(component);
		Preemptives_Type preemptive = Preemptives_Type.Preemptive;
		if (!Properties_With_Default_Value.getPreemptive_Scheduler(component)) {
			preemptive = Preemptives_Type.Not_Preemptive;
		}

		ComponentInstance co = GetProperties.getBoundProcessor(component);
		String cpu_name = "aadl_component_is_not_bound";
		if (co != null) {
			cpu_name = co.getInstanceObjectPath();
		}

		// Instanciate Cheddar ADL entities
		//
		Scheduling_Parameters p = new Scheduling_Parameters();
		p.setPreemptiveType(preemptive);
		p.setSchedulerType(protocol);
		p.setUserDefinedSchedulerSourceFileName(source_text);
		p.setQuantum(quantum);

		Address_Space c = new Address_Space();
		c.setName(name);
		c.setObjectType(Objects_Type.Address_Space_Object_Type);
		c.setScheduling(p);
		c.setcheddarXmlId(id.getAndIncrement());
		c.setCpuName(cpu_name);

		Debug.Put("add address space " + c.getName());

		result.address_spaces.add(c);

	}

}
